@@ -2,11 +2,11 @@
 #######################################################################
 """Open ID authenticator class (use IProfileAnnotation)
 
-$Id: orderinformation.py 52495 2009-02-09 23:30:26Z cray $
+$Id: orderinformation.py 52646 2009-02-16 23:38:16Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 52495 $"
+__version__ = "$Revision: 52646 $"
 
 from ng.lib.orderinformation import OrderInformation
 
@@ -17,4 +17,4 @@ class LeftColumnOrderInformation(OrderInformation) :
     name = [ "rubriccloud", "currentbox", "rubriclist", "fastsearchbox", "topcommunitiesbox", "membersbox", "subscribe",  ]
     
 class RightColumnOrderInformation(OrderInformation) :
-    name = [ "googleadsbox", "toolbox", "loginbox", "newslistbox" ]
+    name = [ "googleadsbox", "loginbox", "toolbox",  "newslistbox" ]
