@@ -2,11 +2,11 @@
 #######################################################################
 """ Special widgets for photosequence adding page
 
-$Id: addcommunity.py 51785 2008-09-25 09:31:02Z cray $
+$Id: addcommunity.py 52412 2009-01-30 11:52:27Z cray $
 """
 __author__  = u"Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51785 $"
+__version__ = "$Revision: 52412 $"
 
 from zope.interface import implements
 from zope.schema import getFieldNames
@@ -14,7 +14,7 @@ from zope.schema import getFieldNames
 from ng.content.article.interfaces import IDocShort 
 from zope.app.zapi import absoluteURL, getUtility
 from zope.app.container.interfaces import INameChooser, IContainer
-from ng.site.content.communityfactory.community import CommunityCreate 
+from ng.site.addon.community.communityfactory.community import CommunityCreate 
 
 class AddCommunity(object) :
     def getData(self,*kv,**kw) :
@@ -23,7 +23,6 @@ class AddCommunity(object) :
     def setData(self,d,**kw) :
         division = getUtility(IContainer,context=self.context,name='community')
         community = CommunityCreate(self.request.principal.id)
-        print d
 
         community.title = d['title']
                 
