@@ -2,11 +2,11 @@
 #######################################################################
 """The definitions of a few viewlet provider.
 
-$Id: interfaces.py 52489 2009-02-09 12:51:27Z cray $
+$Id: interfaces.py 52645 2009-02-16 23:33:08Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 52489 $"
+__version__ = "$Revision: 52645 $"
 
 from zope.viewlet import interfaces
 from ng.skin.base.viewlet.viewletmain.interfaces import INewsListBoxProvider
@@ -24,6 +24,6 @@ class ILeftColumn(ISubscribeProvider,
                   IFastSearchBoxProvider,
                   IRubricAllCloudProvider,
                   IRubricCloudProvider,
-                  IRubricListProvider,
+#                  IRubricListProvider,
                   interfaces.IViewletManager) :
     """ Left Column viewlet"""
